from typing import Any, Dict, Literal, Callable, Optional
from wisecon.types import BaseMapping, APIDataV1RequestData


__all__ = [
    "EarnFast",
    "EarnFastMapping",
]


class EarnFastMapping(BaseMapping):
    """字段映射 上市公司业绩报表"""
    columns: Dict = {
        "SECURITY_CODE": "证券代码",
        "SECURITY_NAME_ABBR": "证券简称",
        "TRADE_MARKET": "交易市场",
        "TRADE_MARKET_CODE": "交易市场代码",
        "SECURITY_TYPE": "证券类型",
        "SECURITY_TYPE_CODE": "证券类型代码",
        "UPDATE_DATE": "更新时间",
        "REPORT_DATE": "报告日期",
        "BASIC_EPS": "基本每股收益",
        "TOTAL_OPERATE_INCOME": "营业总收入",
        "TOTAL_OPERATE_INCOME_SQ": "去年同期营业总收入",
        "PARENT_NETPROFIT": "净利润",
        "PARENT_NETPROFIT_SQ": "去年同期净利润",
        "PARENT_BVPS": "每股净资产",
        "WEIGHTAVG_ROE": "净资产收益率",
        "YSTZ": "营业总收入同比增长率",
        "JLRTBZCL": "净利润同比增长率",
        "DJDYSHZ": "季度环比营业收入增长率",
        "DJDJLHZ": "季度环比净利润增长率",
        "PUBLISHNAME": "发布名称",
        "ORG_CODE": "机构代码",
        "NOTICE_DATE": "公告日期",
        "QDATE": "季度日期",
        "DATATYPE": "数据类型",
        "MARKET": "市场",
        "ISNEW": "是否最新",
        "EITIME": "导入时间",
        "SECUCODE": "证券代码"
    }


class EarnFast(APIDataV1RequestData):
    """查询 上市公司业绩报表"""
    def __init__(
            self,
            security_code: Optional[str] = None,
            size: Optional[int] = 50,
            start_date: Optional[str] = None,
            end_date: Optional[str] = None,
            date: Optional[str] = None,
            industry_name: Optional[str] = None,
            verbose: Optional[bool] = False,
            logger: Optional[Callable] = None,
            **kwargs: Any
    ):
        """
        Notes:
            ```python
            from wisecon.stock.financial import EarnFast

            data = EarnFast(date="2024-09-30", size=5).load()
            data.to_frame(chinese_column=True)
            ```

        Args:
            security_code: 证券代码
            industry_name: 行业名称
            size: 数据条数据
            start_date: 开始日期
            end_date: 结束日期
            date: 指定日期
            verbose: 是否打印日志
            logger: 日志对象
            **kwargs: 其他参数
        """
        self.security_code = security_code
        self.size = size
        self.start_date = start_date
        self.end_date = end_date
        self.date = date
        self.industry_name = industry_name
        self.mapping = EarnFastMapping()
        self.verbose = verbose
        self.logger = logger
        self.kwargs = kwargs
        self.request_set(response_type="json", description="上市公司业绩报表")
        self.conditions = []

    def params_filter(self) -> str:
        """
        :return:
        """
        self.filter_report_date()
        self.filter_security_code()
        if self.industry_name:
            self.conditions.append(f'(PUBLISHNAME="{self.industry_name}")')
        return "".join(self.conditions)

    def params(self) -> Dict:
        """
        :return:
        """
        params = {
            "filter": self.params_filter(),
            "sortColumns": "UPDATE_DATE,SECURITY_CODE",
            "sortTypes": "-1,-1",
            "pageSize": self.size,
            "pageNumber": 1,
            "reportName": "RPT_FCI_PERFORMANCEE",
        }
        return self.base_param(params)



from typing import Any, Dict, Callable, Optional, Literal, List
from wisecon.types import BaseMapping, APICurrentCarRequestData


__all__ = [
    "CarBrandListMapping",
    "CarBrandList",
]


class CarBrandListMapping(BaseMapping):
    """字段映射 汽车品牌列表"""
    columns: Dict = {
        "cat_id": "id",
        "alpha": "alpha",
        "title": "name",
        "key": "key",
    }


class CarBrandList(APICurrentCarRequestData):
    """查询 汽车品牌列表"""
    def __init__(
            self,
            verbose: Optional[bool] = False,
            logger: Optional[Callable] = None,
            **kwargs: Any
    ):
        """
        Notes:
            ```python
            data = CarBrandList().load()
            data.to_frame(chinese_column=True)
            ```

        Args:
            verbose: 是否打印日志
            logger: 自定义日志打印函数
            **kwargs: 其他参数
        """
        self.mapping = CarBrandListMapping()
        self.verbose = verbose
        self.logger = logger
        self.kwargs = kwargs
        self.request_set(description="汽车品牌列表")

    def clean_json(
            self,
            json_data: Optional[Dict],
    ) -> List[Dict]:
        """"""
        data = json_data.pop("data")
        self.metadata.response = json_data

        def clean_item(item: Dict) -> List:
            """"""
            d = item.get("list")
            k = item.get("key")
            [_item.update({"key": k}) for _item in d]
            return d

        data = list(map(clean_item, data))
        return sum(data, [])

    def params(self) -> Dict:
        """"""
        params = {"extra": "getCarBrand",}
        return self.base_param(update=params)



from typing import Any, Dict, Callable, Optional, Literal, Annotated
from wisecon.types import BaseMapping, APIStockKline


__all__ = [
    "KLineMapping",
    "KLine",
]


class KLineMapping(BaseMapping):
    """字段映射 股票-KLine"""
    columns: Dict = {
        "time": "时间",
        "open": "开盘",
        "close": "收盘",
        "high": "最高",
        "low": "最低",
        "volume": "成交量",
        "turnover": "成交额",
        "amplitude": "振幅",
        "change_pct": "涨跌幅",
        "change_amt": "涨跌额",
        "turnover_rate": "换手率"
    }


class KLine(APIStockKline):
    """查询 股票-KLine

    注意：非交易日时，1分钟线`1m`无数据。
    """
    def __init__(
            self,
            market_code: Annotated[Optional[str], "市场代码", False] = None,
            security_code: Annotated[Optional[str], "证券代码", False] = None,
            plate_code: Annotated[Optional[str], "板块代码", False] = None,
            end_date: Annotated[Optional[str], "开始时间", False] = "20500101",
            size: Annotated[Optional[int], "返回数据条数", False] = 120,
            period: Annotated[Literal["1m", "5m", "15m", "30m", "60m", "1D", "1W", "1M"], "", False] = "5m",
            adjust: Annotated[Literal["前复权", "后赋权", "不赋权"], "", False] = "前复权",
            verbose: Annotated[Optional[bool], "是否显示日志", False] = False,
            logger: Annotated[Optional[Callable], "日志对象", False] = None,
            **kwargs: Annotated[Any, "其他参数", False]
    ):
        """
        Notes:
            ```python
            from wisecon.stock.kline import *

            # 0. 查询沪深300 K线数据
            data = KLine(market_code="000300", period="1D", size=5).load()
            data.to_frame(chinese_column=True)

            # 1. 查询股票的 K线数据
            data = KLine(security_code="300069", period="1D", size=5).load()
            data.to_frame(chinese_column=True)

            # 2. 查询板块的 K线数据
            data = KLine(plate_code="BK0887", period="1D", size=5).load()
            print(data.to_markdown(chinese_column=True))
            ```

        Args:
            market_code: 市场代码
            security_code: 股票代码
            plate_code: 板块代码
            end_date: 截止日期
            size: 返回数据条数
            period: K线周期`["1m", "5m", "15m", "30m", "60m", "1D", "1W", "1M"]`
            adjust: 复权类型`["前复权", "后赋权", "不赋权"]`
            verbose: 是否打印日志
            logger: 日志对象
            **kwargs: 其他参数
        """
        self.market_code = market_code
        self.security_code = security_code
        self.plate_code = plate_code
        self.end_date = end_date
        self.size = size
        self.period = period
        self.adjust = adjust
        self.mapping = KLineMapping()
        self.verbose = verbose
        self.logger = logger
        self.kwargs = kwargs
        self.request_set(description="股票-KLine")
        self.validate_date_format(date=end_date, _format="%Y%m%d")

    def params_adjust_type(self) -> int:
        """"""
        adjust_mapping = {"前复权": 1, "后赋权": 2, "不赋权": 0}
        return adjust_mapping[self.adjust]

    def params_period(self) -> str:
        """"""
        period_mapping = {
            "1m": "1", "5m": "5", "15m": "15", "30m": "30", "60m": "60",
            "1D": "101", "1W": "102", "1M": "103"
        }
        return period_mapping[self.period]

    def params_secid(self) -> str:
        """"""
        if self.market_code:
            return f"1.{self.market_code}"
        elif self.security_code:
            if self.security_code.startswith("6"):
                return f"1.{self.security_code}"
            else:
                return f"0.{self.security_code}"
        elif self.plate_code:
            return f"90.{self.plate_code}"

    def params(self) -> Dict:
        """
        :return:
        """
        params = {
            "secid": self.params_secid(),
            "fields1": "f1,f2,f3,f4,f5,f6",
            "fields2": "f51,f52,f53,f54,f55,f56,f57,f58,f59,f60,f61",
            "klt": self.params_period(),
            "fqt": self.params_adjust_type(),
            "end": self.end_date,
            "lmt": self.size,
        }
        return params



from typing import Any, Dict, Callable, Optional, Literal
from wisecon.types import BaseMapping, APICurrentCarRequestData


__all__ = [
    "CurrentCarSalesMapping",
    "CurrentCarSales",
]


class CurrentCarSalesMapping(BaseMapping):
    """字段映射 汽车当前销量排行榜"""
    columns: Dict = {
        "date": "日期",
        "num": "数量",
        "levelId": "级别ID",
        "level": "车型级别",
        "factoryId": "厂商ID",
        "title": "厂商名称",
        "styleId": "车型ID",
        "bodyId": "车身ID",
        "body": "车身类别",
        "brandId": "品牌ID",
    }


class CurrentCarSales(APICurrentCarRequestData):
    """查询 汽车当前销量排行榜"""
    def __init__(
            self,
            data_type: Literal["销量", "品牌销量", "厂商销量", "车型级别", "车身类别", "车型销量", "电动车销量"] = "销量",
            start_date: Optional[str] = None,
            end_date: Optional[str] = None,
            verbose: Optional[bool] = False,
            logger: Optional[Callable] = None,
            **kwargs: Any
    ):
        """
        Notes:
            ```python
            data = CurrentCarSales(data_type="电动车销量",).load()
            data.to_frame(chinese_column=True)
            ```

        Args:
            data_type: 查询类型
            start_date: 开始日期, %Y-%m
            end_date: 结束日期, %Y-%m
            verbose: 是否打印日志
            logger: 自定义日志打印函数
            **kwargs: 其他参数
        """
        self.data_type = data_type
        self.start_date = start_date
        self.end_date = end_date
        self.mapping = CurrentCarSalesMapping()
        self.verbose = verbose
        self.logger = logger
        self.kwargs = kwargs
        self.request_set(description="汽车当前销量排行榜")
        self.conditions = []
        self.validate_date_format(date=[start_date, end_date], _format="%Y-%m")

    def params_ranking(self) -> str:
        """"""
        rank_mapping = {
            "销量": "monthRanking",
            "车型级别": "levelRanking",
            "厂商销量": "factoryRanking",
            "车型销量": "styleRanking",
            "车身类别": "bodyRanking",
            "品牌销量": "brandRanking",
            "电动车销量": "evRanking",
        }
        return rank_mapping[self.data_type]

    def params(self) -> Dict:
        """"""
        params = {
            "extra": self.params_ranking(),
            "fromDate": self.start_date,
            "toDate": self.end_date,
        }
        params = self.params_drop_none(params=params)
        return self.base_param(update=params)



from typing import Any, Dict, Callable, Optional, Annotated
from wisecon.types import BaseMapping
from wisecon.types.request_api.movie import APIMovieRequestData


__all__ = [
    "MovieMapping",
    "Movie",
]


class MovieMapping(BaseMapping):
    """字段映射 当前实时电影票房"""
    columns: Dict = {
        "boxDesc": "票房描述",
        "boxRate": "票房占比",
        "movieId": "电影ID",
        "movieName": "电影名称",
        "releaseInfo": "上映信息",
        "seatCountRate": "座位使用率",
        "showCountRate": "场次占比",
        "sumBoxDesc": "总票房描述"
    }


class Movie(APIMovieRequestData):
    """查询 当前实时电影票房"""
    def __init__(
            self,
            verbose: Annotated[Optional[bool], "", False] = False,
            logger: Annotated[Optional[Callable], "", False] = None,
            **kwargs: Annotated[Any, "", False],
    ):
        """
        Notes:
            ```python
            from wisecon.movie import *

            # 查询 当前实时电影票房
            data = Movie().load()
            data.to_frame(chinese_column=True)
            ```

        Args:
            verbose: 是否打印日志
            logger: 自定义日志
            **kwargs: 其他参数
        """
        self.mapping = MovieMapping()
        self.verbose = verbose
        self.logger = logger
        self.kwargs = kwargs
        self.request_set(
            response_type="json",
            description="电影票房",
        )

    def params(self) -> Dict:
        """
        :return:
        """
        params = {}
        return self.base_param(update=params)



import unittest
import json
from sseclient import SSEClient

from wisecon.utils import headers


class TestSSE(unittest.TestCase):
    def test_sse(self):
        url = "https://push2.eastmoney.com/api/qt/stock/sse?fields=f58,f734,f107,f57,f43,f59,f169,f301,f60,f170,f152,f177,f111,f46,f44,f45,f47,f260,f48,f261,f279,f277,f278,f288,f19,f17,f531,f15,f13,f11,f20,f18,f16,f14,f12,f39,f37,f35,f33,f31,f40,f38,f36,f34,f32,f211,f212,f213,f214,f215,f210,f209,f208,f207,f206,f161,f49,f171,f50,f86,f84,f85,f168,f108,f116,f167,f164,f162,f163,f92,f71,f117,f292,f51,f52,f191,f192,f262,f294,f295,f269,f270,f256,f257,f285,f286,f748,f747&mpi=1000&invt=2&fltt=1&secid=0.301618&ut=fa5fd1943c7b386f172d6893dbfba10b&dect=1&wbp2u=|0|0|0|web"
        import requests
        from sseclient import SSEClient

        # 目标 URL

        # 发送请求并获取响应
        response = requests.get(url, stream=True)
        for resp in response:
            print(resp)

"""
https://5.push2.eastmoney.com/api/qt/stock/details/sse?
fields1=f1,f2,f3,f4
&fields2=f51,f52,f53,f54,f55
&mpi=1000
&dect=1
&fltt=2
&pos=-11
&secid=0.301618
&wbp2u=|0|0|0|web
"""


import pyecharts.options as opts
from pyecharts.charts import Line
from typing import List, Optional
import numpy as np


__all__ = [
    "PEChart"
]


class PEChart:
    """"""
    def __init__(
            self,
            x: List[str],
            y: List[float],
            title: Optional[str] = None,
            width: Optional[str] = "1000px",
            height: Optional[str] = "600px",
            q: Optional[List[float]] = None,
    ):
        """"""
        self.x = x
        self.y = y
        self.width = width if width is not None else "1000px"
        self.height = height if height is not None else "600px"
        self.title = title if title is not None else "PE Chart"
        if q is None:
            self.q = [0.15, 0.5, 0.85]
        else:
            self.q = q

    def line_chart(self, ):
        """"""
        min_ = round(min(self.y) - min(self.y) * 0.1, 2)
        max_ = round(max(self.y) + max(self.y) * 0.1, 2)
        pe_buy, pe_mid, pe_sell = np.quantile(self.y, self.q)
        markline_data = [
            opts.MarkLineItem(y=pe_buy),
            opts.MarkLineItem(y=pe_mid),
            opts.MarkLineItem(y=pe_sell)
        ]

        chart = Line(
            init_opts=opts.InitOpts(width=self.width, height=self.height)
        )
        chart.add_xaxis(self.x)
        chart.add_yaxis(
            "PE", self.y,
            areastyle_opts=opts.AreaStyleOpts(opacity=0.1),
            markline_opts=opts.MarkLineOpts(data=markline_data),
        )
        chart.set_global_opts(
            title_opts=opts.TitleOpts(title=self.title),
            yaxis_opts=opts.AxisOpts(min_=min_, max_=max_),
            toolbox_opts=opts.ToolboxOpts(is_show=True),
            datazoom_opts=[opts.DataZoomOpts(type_="inside", range_end=100)],
        )
        return chart

    def render(self, path: str):
        """"""
        chart = self.line_chart()
        chart.render(path)



from typing import *
from pydantic import BaseModel
from typing import List, Dict, Optional


__all__ = [
    "ToolParameters",
    "ToolFunction",
    "ToolItem",
    "Function",
]


class ToolParameters(BaseModel):
    """"""
    type: str = "object"
    properties: Dict[str, Dict]
    required: List[str]


class ToolFunction(BaseModel):
    """"""
    name: str
    description: str
    parameters: ToolParameters


class ToolItem(BaseModel):
    type: str = "function"
    function: ToolFunction


class Function(BaseModel):
    arguments: Optional[Union[str, Dict]] = None
    """
    The arguments to call the function with, as generated by the model in JSON
    format. Note that the model does not always generate valid JSON, and may
    hallucinate parameters not defined by your function schema. Validate the
    arguments in your code before calling your function.
    """

    name: str
    """The name of the function to call."""

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        if isinstance(self.arguments, str):
            self.arguments = eval(self.arguments)



import unittest


class TestDuckDB(unittest.TestCase):
    def test_duckdb(self):
        """"""
        import duckdb
        r1 = duckdb.sql("SELECT 42 AS i")
        print(r1)
        duckdb.sql("SELECT i * 2 AS k FROM r1").show()

    def test_save(self):
        """"""
        import duckdb
        import pandas as pd
        from sqlalchemy import create_engine

        # 创建示例 DataFrame
        data = {'name': ['Alice', 'Bob', 'Charlie'], 'age': [25, 30, 35]}
        df = pd.DataFrame(data)

        # 创建 DuckDB 数据库连接
        engine = create_engine('duckdb:///my_database.duckdb')  # 或者使用 'duckdb:///path/to/my_database.duckdb'
        # engine = duckdb.connect('my_database.duckdb')

        # 使用 to_sql 将 DataFrame 存入 DuckDB
        df.to_sql('my_table', con=engine, if_exists='replace', index=False)

    def test_read(self):
        """"""
        import pandas as pd
        from sqlalchemy import create_engine

        # 创建 DuckDB 数据库连接
        engine = create_engine('duckdb:///my_database.duckdb')  # 或者使用 'duckdb:///path/to/my_database.duckdb'
        df = pd.read_sql("my_table", con=engine)
        print(df)

    def test_(self):
        """"""
        import pandas as pd
        from sqlalchemy import create_engine

        engine = create_engine('duckdb:////home/data/duckdb/valuation.db')
        df = pd.read_sql("industry", con=engine)
        print(df.shape)
        code = "016029"
        df_code = df[df.BOARD_CODE == code]
        df_code = df_code.sort_values("TRADE_DATE")




from typing import Any, Dict, Callable, Optional, Annotated
from wisecon.types import BaseMapping, APIMarketSummary


__all__ = [
    "LastDayMarketSummaryMapping",
    "LastDayMarketSummary",
]


class LastDayMarketSummaryMapping(BaseMapping):
    """字段映射 市场总貌"""
    columns: Dict = {
        "nt": "市场名称",
        "td": "交易日期",
        "v": "成交量",
        "tv": "成交金额",
        "ts": "总市值",
        "ns": "新股数量",
        "cn": "公司数量",
        "ttm": "市盈率(TTM)"
    }


class LastDayMarketSummary(APIMarketSummary):
    """查询 查询昨日市场（深市、沪市、创业板）总体交易数据"""
    def __init__(
            self,
            verbose: Annotated[Optional[bool], "", False] = False,
            logger: Annotated[Optional[Callable], "", False] = None,
            **kwargs: Annotated[Any, "", False],
    ):
        """
        Notes:
            ```python
            from wisecon.stock.market import *

            # 市场总貌：查询昨日市场（深市、沪市、创业板）总体交易数据
            data = LastDayMarketSummary().load()
            data.to_frame(chinese_column=True)
            ```

        Args:
            verbose: 是否打印日志
            logger: 自定义日志打印函数
            **kwargs: 其他参数
        """
        self.mapping = LastDayMarketSummaryMapping()
        self.verbose = verbose
        self.logger = logger
        self.kwargs = kwargs
        self.request_set(description="市场总貌")

    def params(self) -> Dict:
        """"""
        return {}



import re
from typing import List, Dict, Tuple
from .parse import ParseBase


__all__ = ['ParseDict']


class ParseDict(ParseBase):
    """"""
    matches: List[str] = None
    pattern: str = r'\{.*?\}'
    greedy_pattern: str = r'\{.*\}'
    # key_val_pattern = r"'([^']+)': '([^']*)'"
    key_val_pattern = r"['\"](\w+)['\"]:\s*['\"]([^'\"]+)['\"]"
    mark: Tuple[str] = ("{", "}")

    @classmethod
    def greedy_dict(cls, string: str, ) -> List[dict]:
        """
        解析dict贪婪模式，寻找第一个 '{' 到最后一个 '}' 之间的内容，适用于文本中只有 1 个字典的解析。
        :param string:
        :return:
        """
        return cls.greedy_mark(string=string, mark_pattern=cls.greedy_pattern)

    @classmethod
    def eval_dict(cls, string: str) -> List[Dict]:
        """
        解析dict非贪婪模式，寻找任意 '{' 之间 '}' 之间的内容，适用于存在多个非嵌套模型字典的解析。
        :param string:
        :return:

        example:

        """
        return cls.eval_mark(string=string, mark_pattern=cls.pattern)

    @classmethod
    def nested_dict(cls, string: str) -> List[Dict]:
        """
        解析嵌套的 dict，基本适用于全部情况的字典解析。
        :param string:
        :return:

        example:

        """
        return cls.nested_data(string=string, mark=cls.mark)

    @classmethod
    def key_value_dict(cls, string: str) -> List[Dict]:
        """
        todo: 还需要考虑单引号、双引号、还有多行识别未解决，有点麻烦
        依据冒号对 key-value 提取。
        :param string:
        :return:
        """
        tuple_data = re.findall(cls.key_val_pattern, string)
        return [dict(tuple_data)]



import re
import time
import click
from pydantic import Field
from fastmcp import FastMCP
from typing import Union, Literal, Annotated
from wisecon.report import Report, ConceptionMap
from wisecon.mcp.validate import *
from mcp.server.session import ServerSession


####################################################################################
# Temporary monkeypatch which avoids crashing when a POST message is received
# before a connection has been initialized, e.g: after a deployment.
# pylint: disable-next=protected-access
old__received_request = ServerSession._received_request


async def _received_request(self, *args, **kwargs):
    try:
        return await old__received_request(self, *args, **kwargs)
    except RuntimeError:
        pass


# pylint: disable-next=protected-access
ServerSession._received_request = _received_request
####################################################################################


mcp = FastMCP("Wisecon MCP")


@mcp.tool()
def get_now_date():
    """获取当前日期"""
    return time.strftime("%Y-%m-%d", time.localtime())


@mcp.tool()
def get_industry_name_by_code(code: Annotated[str, Field(description="行业代码")]) -> str:
    """根据行业代码获取行业名称"""
    con_map = ConceptionMap()
    return validate_response_data(con_map.get_name_by_code(code))


@mcp.tool()
def get_industry_code_by_name(keyword: Annotated[str, Field(description="行业名称关键词")]) -> str:
    """根据行业名称关键词进行模糊查询，获取与该关键词匹配的行业代码"""
    con_map = ConceptionMap()
    return validate_response_data(con_map.get_code_by_name(keyword))


@mcp.tool()
def list_industry() -> dict:
    """获取行业列表"""
    con_map = ConceptionMap()
    df_industry = con_map.map_industry.to_frame()
    data = dict(zip(df_industry.bkCode, df_industry.bkName))
    return data


@mcp.tool()
def list_report(
        report_type: Annotated[Literal["个股研报", "行业研报", "策略报告", "宏观研究", "券商晨报", "*"], Field(description="研报类型，'*' 为不限定研报类型")],
        code: Annotated[str, Field(description="股票代码, 如600000")] = None,
        industry_code: Annotated[Union[str, int], Field(description="行业代码(如 '451'), '*' 为不限定行业")] = "*",
        date: Annotated[str, Field(description="研报发布日期(yyyy-MM-dd, 如：2024-09-23), 默认为查询当天")] = None,
        size: Annotated[int, Field(description="获取研报数量，默认10")] = 10,
):
    """List all available reports.

    industry_code: 行业代码可以查询 tool `get_industry_code_by_name` 获取行业代码
    """
    if date is None:
        date = time.strftime("%Y-%m-%d", time.localtime())
    report = Report(
        code=code, industry_code=industry_code, begin_time=date,
        end_time=date, report_type=report_type, size=size)
    data = report.load()
    if len(data.data) > 0:
        df_data = data.to_frame()
        columns = ["title", "orgSName", "infoCode"]
        if "industryName" in df_data.columns:
            columns.append("industryName")
        return validate_response_data(df_data[columns])
    else:
        return "No data found."

@mcp.tool()
def fetch_report_text_by_code(
        info_code: Annotated[str, Field(description="研报信息代码")]
) -> str:
    """Fetch report data."""
    if re.match(r"^AP\d+$", info_code):
        report = Report()
        text = report.to_text(info_code=info_code)
        return text
    else:
        return "请输入正确的研报信息代码，如：`AP202505061668519723`"


@click.command()
@click.option("--port", "-p", default=8000, type=int, required=False, help="port")
@click.option("--transport", "-p", default="stdio", type=str, required=False, help="transport")
def report_mcp_server(
        transport: Literal["stdio", "sse"] = "stdio",
        port: Union[int, str] = None,
) -> None:
    """"""
    if transport == "sse":
        mcp.run(transport=transport, port=port)
    else:
        mcp.run(transport=transport)


if __name__ == "__main__":
    mcp.run(transport="sse", port=8002)
